/****************************************************************************
** Meta object code from reading C++ file 'dic_tools_widget.h'
**
** Created: Sat Feb 6 15:10:00 2010
**      by: The Qt Meta Object Compiler version 61 (Qt 4.5.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../qt/dic_tools_widget.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dic_tools_widget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 61
#error "This file was generated using the moc from 4.5.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_DicToolsWidget[] = {

 // content:
       2,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   12, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors

 // slots: signature, parameters, type, tag, flags
      21,   16,   15,   15, 0x0a,
      53,   47,   15,   15, 0x0a,
      75,   15,   15,   15, 0x08,
      90,   15,   15,   15, 0x08,
     105,   15,   15,   15, 0x08,
     121,   15,   15,   15, 0x08,

       0        // eod
};

static const char qt_meta_stringdata_DicToolsWidget[] = {
    "DicToolsWidget\0\0iDic\0setDic(const Dictionary*)\0"
    "iRack\0setPlus1Rack(QString)\0refreshCheck()\0"
    "refreshPlus1()\0refreshRegexp()\0"
    "refreshDicInfo()\0"
};

const QMetaObject DicToolsWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_DicToolsWidget,
      qt_meta_data_DicToolsWidget, 0 }
};

const QMetaObject *DicToolsWidget::metaObject() const
{
    return &staticMetaObject;
}

void *DicToolsWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_DicToolsWidget))
        return static_cast<void*>(const_cast< DicToolsWidget*>(this));
    return QWidget::qt_metacast(_clname);
}

int DicToolsWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: setDic((*reinterpret_cast< const Dictionary*(*)>(_a[1]))); break;
        case 1: setPlus1Rack((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: refreshCheck(); break;
        case 3: refreshPlus1(); break;
        case 4: refreshRegexp(); break;
        case 5: refreshDicInfo(); break;
        default: ;
        }
        _id -= 6;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
